@@ -21,9 +21,9 @@
 #include <iostream.h>
 #include <iomanip.h>
 #include <fstream.h>
+#include <string.h>
 
 #include <stdlib.h>
-#include <string.h>
 #ifdef __MSDOS__
 #include <dir.h>
 #endif
@@ -224,43 +224,43 @@ int main(int argc, char *argv[])
 				break;
 			}
 #endif
-            if ( strnicmp( &argv[a][1], "fout", 4 ) == 0 )
+            if ( myStrNcaseCmp( &argv[a][1], "fout" ) == 0 )
 			{
 				fadeOut.seconds = atoi(argv[a]+5);
 			}
-            else if ( strnicmp( &argv[a][1], "fin", 3 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "fin" ) == 0 )
 			{
 				fadeIn.seconds = atoi(argv[a]+4);
 			}
-            else if ( strnicmp( &argv[a][1], "nf", 2 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "nf" ) == 0 )
 			{
 				myEmuConfig.emulateFilter = false;
 			}
-            else if ( strnicmp( &argv[a][1], "ns", 2 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "ns" ) == 0 )
 			{
                 myEmuConfig.mos8580 = true;
 			}
-            else if ( strnicmp( &argv[a][1], "a2", 2 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "a2" ) == 0 )
 			{
 				myEmuConfig.memoryMode = MPU_TRANSPARENT_ROM;
 			}
-            else if ( strnicmp( &argv[a][1], "a", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "a" ) == 0 )
 			{
 				myEmuConfig.memoryMode = MPU_PLAYSID_ENVIRONMENT;
 			}
-            else if ( strnicmp( &argv[a][1], "b", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "b" ) == 0 )
 			{
 				secondsToSkip = atoi(argv[a]+2);
 			}
-            else if ( strnicmp( &argv[a][1], "f", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "f" ) == 0 )
 			{
 				myEmuConfig.frequency = (ulong)atoi(argv[a]+2);
 			}
-            else if ( strnicmp( &argv[a][1], "h", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "h" ) == 0 )
 			{
 				printtext(ERR_SYNTAX);
 			}
-            else if ( strnicmp( &argv[a][1], "m", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "m" ) == 0 )
 			{
 				for ( ubyte j = 2; j < strlen(argv[a]); j++ )
 				{
@@ -271,33 +271,33 @@ int main(int argc, char *argv[])
 				}
 				myEmuConfig.volumeControl = SIDEMU_VOLCONTROL;
 			}
-            else if ( strnicmp( &argv[a][1], "n", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "n" ) == 0 )
 			{
 				myEmuConfig.clockSpeed = SIDTUNE_CLOCK_NTSC;
 				myEmuConfig.forceSongSpeed = true;
 			}
-            else if ( strnicmp( &argv[a][1], "o", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "o" ) == 0 )
 			{
 				selectedSong = atoi(argv[a]+2);
 			}
-            else if ( strnicmp( &argv[a][1], "t", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "t" ) == 0 )
 			{
 				seconds = atoi(argv[a]+2);
 			}
-            else if ( strnicmp( &argv[a][1], "ss", 2 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "ss" ) == 0 )
 			{
 				myEmuConfig.channels = SIDEMU_STEREO;
 				myEmuConfig.volumeControl = SIDEMU_STEREOSURROUND;
 			}
-            else if ( strnicmp( &argv[a][1], "s", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "s" ) == 0 )
 			{
 				myEmuConfig.channels = SIDEMU_STEREO;
 			}
-            else if ( strnicmp( &argv[a][1], "u", 1 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "u" ) == 0 )
 			{
 				flags |= FLAG_ULAW;
 			}
-            else if ( strnicmp( &argv[a][1], "16", 2 ) == 0 )
+            else if ( myStrNcaseCmp( &argv[a][1], "16" ) == 0 )
 			{
 				myEmuConfig.bitsPerSample = SIDEMU_16BIT;
 			}
@@ -488,11 +488,11 @@ int main(int argc, char *argv[])
 
 	// Open output file stream.
 #if defined(SID_HAVE_IOS_BIN)
-    ofstream waveFile( waveFileName, ios::out | ios::bin | ios::noreplace );
+    ofstream waveFile( waveFileName, ios::out|ios::bin|ios::app );
 #else
-	ofstream waveFile( waveFileName, ios::out | ios::binary | ios::noreplace );
+	ofstream waveFile( waveFileName, ios::out|ios::binary|ios::app );
 #endif
-	if ( !waveFile )
+	if ( !waveFile || waveFile.tellp()>0 )
 	{
         cerr << "ERROR: Cannot create output file " << "``" << waveFileName << "'', "
             << "probably already exits." << endl;
@@ -514,7 +514,7 @@ int main(int argc, char *argv[])
 #endif
 		sampleBufferSize = myEmuConfig.frequency * 2;
 		headerSize = sizeof(au_hdr);
-        waveFile.write( (unsigned char*)&my_au_hdr, headerSize );
+        waveFile.write( (char*)&my_au_hdr, headerSize );
 	}
 	else
 	{
@@ -534,13 +534,13 @@ int main(int argc, char *argv[])
 #else
 		my_wav_hdr.bitspersmpl = convertEndianess ((uword)myEmuConfig.bitsPerSample);
 		my_wav_hdr.bytespersmpl = convertEndianess ((uword)bytesPerSample);
-		my_wav_hdr.samplefreq = convertEndianess (myEmuConfig.frequency);
+		my_wav_hdr.samplefreq = convertEndianess ((udword)myEmuConfig.frequency);
 		my_wav_hdr.modus = convertEndianess ((uword)myEmuConfig.channels);
 		my_wav_hdr.bytespersec = convertEndianess ((udword)bytesPerSecond);
 		my_wav_hdr.length = convertEndianess (dataLength + headerSize - 8);
 		my_wav_hdr.data_length = convertEndianess (dataLength);
 #endif
-        waveFile.write( (unsigned char*)&my_wav_hdr, headerSize );
+        waveFile.write( (char*)&my_wav_hdr, headerSize );
 	}
 
 	// Make a buffer that holds 1 second of audio data.
@@ -603,7 +603,7 @@ int main(int argc, char *argv[])
 		if (flags & FLAG_ULAW)
 		{
 			buffer2ulaw(sampleBuffer, sampleBufferSize);
-			waveFile.write( sampleBuffer, sampleBufferSize / 2 );
+			waveFile.write( (char*)sampleBuffer, sampleBufferSize / 2 );
 		}
 		else
 		{
@@ -613,7 +613,7 @@ int main(int argc, char *argv[])
 				endianswitch_buffer( sampleBuffer, sampleBufferSize );
 			}
 #endif
-			waveFile.write( sampleBuffer, sampleBufferSize );
+			waveFile.write( (char*)sampleBuffer, sampleBufferSize );
 		}
 
 		// Print progress report.
